"""
git-pw -- A tool for integrating Git with Patchwork, the web-based patch
tracking system.
"""

import importlib.metadata

__version__ = importlib.metadata.version('git-pw')
